external yaml_get_version_string: unit -> string =
	"mlyaml_get_version_string";;

external yaml_get_version: unit -> int * int * int =
	"mlyaml_get_version";;

type yaml_version_directive = int * int;; (* major, minor *)
type yaml_tag_directive = string * string;; (* handle, prefix *)

type yaml_encoding =
	| YAML_ANY_ENCODING
	| YAML_UTF8_ENCODING
	| YAML_UTF16LE_ENCODING
	| YAML_UTF16BE_ENCODING;;

type yaml_break =
	| YAML_ANY_BREAK
	| YAML_CR_BREAK
	| YAML_LN_BREAK
	| YAML_CRLN_BREAK;;

type yaml_error_type =
	| YAML_NO_ERROR
	| YAML_MEMORY_ERROR
	| YAML_READER_ERROR
	| YAML_SCANNER_ERROR
	| YAML_PARSER_ERROR
	| YAML_COMPOSER_ERROR
	| YAML_WRITER_ERROR
	| YAML_EMITTER_ERROR;;

exception YamlError of yaml_error_type * string;;

Callback.register_exception "YamlError" (YamlError (YAML_NO_ERROR, ""));;

type yaml_mark = int * int * int;; (* index, line, column *)

type yaml_scalar_style =
	| YAML_ANY_SCALAR_STYLE
	| YAML_PLAIN_SCALAR_STYLE
	| YAML_SINGLE_QUOTED_SCALAR_STYLE
	| YAML_DOUBLE_QUOTED_SCALAR_STYLE
	| YAML_LITERAL_SCALAR_STYLE
	| YAML_FOLDED_SCALAR_STYLE;;

type yaml_sequence_style =
	| YAML_ANY_SEQUENCE_STYLE
	| YAML_BLOCK_SEQUENCE_STYLE
	| YAML_FLOW_SEQUENCE_STYLE;;

type yaml_mapping_style =
	| YAML_ANY_MAPPING_STYLE
	| YAML_BLOCK_MAPPING_STYLE
	| YAML_FLOW_MAPPING_STYLE;;

type yaml_event =
	| YAML_NO_EVENT
	| YAML_STREAM_START_EVENT of
		yaml_encoding
	| YAML_STREAM_END_EVENT
	| YAML_DOCUMENT_START_EVENT of
		yaml_version_directive option *
		yaml_tag_directive list *
		bool (* implicit *)
	| YAML_DOCUMENT_END_EVENT of
		bool (* implicit *)
	| YAML_ALIAS_EVENT of
		string (* anchor *)
	| YAML_SCALAR_EVENT of
		string * (* anchor *)
		string * (* tag *)
		string * (* value *)
		bool * (* plain_implicit *)
		bool * (* quoted_implicit *)
		yaml_scalar_style
	| YAML_SEQUENCE_START_EVENT of
		string * (* anchor *)
		string * (* tag *)
		bool * (* implicit *)
		yaml_sequence_style
	| YAML_SEQUENCE_END_EVENT
	| YAML_MAPPING_START_EVENT of
		string * (* anchor *)
		string * (* tag *)
		bool * (* implicit *)
		yaml_mapping_style
	| YAML_MAPPING_END_EVENT;;

type yaml_event_with_mark = yaml_event * yaml_mark * yaml_mark;;

let yaml_null_tag: string = "tag:yaml.org,2002:null";;
let yaml_bool_tag: string = "tag:yaml.org,2002:bool";;
let yaml_str_tag: string = "tag:yaml.org,2002:str";;
let yaml_int_tag: string = "tag:yaml.org,2002:int";;
let yaml_float_tag: string = "tag:yaml.org,2002:float";;
let yaml_timestamp_tag: string = "tag:yaml.org,2002:timestamp";;
let yaml_seq_tag: string = "tag:yaml.org,2002:seq";;
let yaml_map_tag: string = "tag:yaml.org,2002:map";;
let yaml_default_scalar_tag: string = yaml_str_tag;;
let yaml_default_sequence_tag: string = yaml_seq_tag;;
let yaml_default_mapping_tag: string = yaml_map_tag;;

type yaml_read_handler = string -> int -> int -> int;;

type yaml_parser;;

external yaml_parser_initialize: yaml_read_handler -> yaml_parser =
	"mlyaml_parser_initialize";;

external yaml_parser_set_encoding: yaml_parser -> yaml_encoding -> unit =
	"mlyaml_parser_set_encoding";;

external yaml_parser_parse: yaml_parser -> yaml_event_with_mark =
	"mlyaml_parser_parse";;

external yaml_parser_problem_mark: yaml_parser -> yaml_mark =
	"mlyaml_parser_problem_mark";;

type yaml_write_handler = string -> int -> int -> unit;;

type yaml_emitter;;

external yaml_emitter_initialize: yaml_write_handler -> yaml_emitter =
	"mlyaml_emitter_initialize";;

external yaml_emitter_set_canonical: yaml_emitter -> bool -> unit =
	"mlyaml_emitter_set_canonical";;

external yaml_emitter_set_indent: yaml_emitter -> int -> unit =
	"mlyaml_emitter_set_indent";;

external yaml_emitter_set_width: yaml_emitter -> int -> unit =
	"mlyaml_emitter_set_width";;

external yaml_emitter_set_unicode: yaml_emitter -> bool -> unit =
	"mlyaml_emitter_set_unicode";;

external yaml_emitter_set_break: yaml_emitter -> yaml_break -> unit =
	"mlyaml_emitter_set_break";;

external yaml_emitter_emit: yaml_emitter -> yaml_event -> unit =
	"mlyaml_emitter_emit";;

external yaml_emitter_flush: yaml_emitter -> unit =
	"mlyaml_emitter_flush";;
