(* based on libyaml 0.1.2 *)

val yaml_get_version_string: unit -> string;;
val yaml_get_version: unit -> int * int * int;;

type yaml_version_directive = int * int;; (* major, minor *)
type yaml_tag_directive = string * string;; (* handle, prefix *)

type yaml_encoding =
	| YAML_ANY_ENCODING
	| YAML_UTF8_ENCODING
	| YAML_UTF16LE_ENCODING
	| YAML_UTF16BE_ENCODING;;

type yaml_break =
	| YAML_ANY_BREAK
	| YAML_CR_BREAK
	| YAML_LN_BREAK
	| YAML_CRLN_BREAK;;

type yaml_error_type =
	| YAML_NO_ERROR
	| YAML_MEMORY_ERROR
	| YAML_READER_ERROR
	| YAML_SCANNER_ERROR
	| YAML_PARSER_ERROR
	| YAML_COMPOSER_ERROR
	| YAML_WRITER_ERROR
	| YAML_EMITTER_ERROR;;

exception YamlError of yaml_error_type * string;;

type yaml_mark = int * int * int;; (* index, line, column *)

type yaml_scalar_style =
	| YAML_ANY_SCALAR_STYLE
	| YAML_PLAIN_SCALAR_STYLE
	| YAML_SINGLE_QUOTED_SCALAR_STYLE
	| YAML_DOUBLE_QUOTED_SCALAR_STYLE
	| YAML_LITERAL_SCALAR_STYLE
	| YAML_FOLDED_SCALAR_STYLE;;

type yaml_sequence_style =
	| YAML_ANY_SEQUENCE_STYLE
	| YAML_BLOCK_SEQUENCE_STYLE
	| YAML_FLOW_SEQUENCE_STYLE;;

type yaml_mapping_style =
	| YAML_ANY_MAPPING_STYLE
	| YAML_BLOCK_MAPPING_STYLE
	| YAML_FLOW_MAPPING_STYLE;;

(* token definitions are skipped. *)

type yaml_event =
	| YAML_NO_EVENT
	| YAML_STREAM_START_EVENT of
		yaml_encoding
	| YAML_STREAM_END_EVENT
	| YAML_DOCUMENT_START_EVENT of
		yaml_version_directive option *
		yaml_tag_directive list *
		bool (* implicit *)
	| YAML_DOCUMENT_END_EVENT of
		bool (* implicit *)
	| YAML_ALIAS_EVENT of
		string (* anchor *)
	| YAML_SCALAR_EVENT of
		string * (* anchor *)
		string * (* tag *)
		string * (* value *)
		bool * (* plain_implicit *)
		bool * (* quoted_implicit *)
		yaml_scalar_style
	| YAML_SEQUENCE_START_EVENT of
		string * (* anchor *)
		string * (* tag *)
		bool * (* implicit *)
		yaml_sequence_style
	| YAML_SEQUENCE_END_EVENT
	| YAML_MAPPING_START_EVENT of
		string * (* anchor *)
		string * (* tag *)
		bool * (* implicit *)
		yaml_mapping_style
	| YAML_MAPPING_END_EVENT;;

type yaml_event_with_mark = yaml_event * yaml_mark * yaml_mark;;

(* event functions are skipped. *)

val yaml_null_tag: string;;
val yaml_bool_tag: string;;
val yaml_str_tag: string;;
val yaml_int_tag: string;;
val yaml_float_tag: string;;
val yaml_timestamp_tag: string;;
val yaml_seq_tag: string;;
val yaml_map_tag: string;;
val yaml_default_scalar_tag: string;;
val yaml_default_sequence_tag: string;;
val yaml_default_mapping_tag: string;;

(* node/document definitions are skipped. *)

type yaml_read_handler = string -> int -> int -> int;;

type yaml_parser;;

val yaml_parser_initialize: yaml_read_handler -> yaml_parser;;

val yaml_parser_set_encoding: yaml_parser -> yaml_encoding -> unit;;

(* yaml_parser_scan function is skipped. *)

val yaml_parser_parse: yaml_parser -> yaml_event_with_mark;;

val yaml_parser_problem_mark: yaml_parser -> yaml_mark;;

(* yaml_parser_load function is skipped. *)

type yaml_write_handler = string -> int -> int -> unit;;

type yaml_emitter;;

val yaml_emitter_initialize: yaml_write_handler -> yaml_emitter;;

val yaml_emitter_set_canonical: yaml_emitter -> bool -> unit;;
val yaml_emitter_set_indent: yaml_emitter -> int -> unit;;
val yaml_emitter_set_width: yaml_emitter -> int -> unit;;
val yaml_emitter_set_unicode: yaml_emitter -> bool -> unit;;
val yaml_emitter_set_break: yaml_emitter -> yaml_break -> unit;;

val yaml_emitter_emit: yaml_emitter -> yaml_event -> unit;;

(* yaml_emitter's document functions are skipped. *)

val yaml_emitter_flush: yaml_emitter -> unit;;
